/*
 * PruebaMySQL.java
 *
 * Ejemplo para meter, de forma automtica, un ResultSet en un JTable
 * El usuario y password de conexin con la base de datos debe cambiarse.
 * En la base de datos se supone que hay una base de datos llamada prueba y que
 * tiene una tabla persona con tres campos, de esta manera:
 * mysql> create database prueba;
 * mysql> use prueba;
 * mysql> create table persona (id smallint auto_increment, nombre varchar(60), 
 *      nacimiento date, primary key(id)); 
 */

package chuidiang.ejemplos.base_datos;

import java.sql.*;

import javax.swing.table.DefaultTableModel;

/**
 * Clase de prueba de conexin con una base de datos MySQL
 */
public class PruebaMySQL
{
    /** Clase para manejo de la base de datos */
    private BaseDeDatos bd;

    /** Clase encargada de construir y visualizar la ventana */
    private TablaDeDatos tabla;

    /** Clase donde se guardan los datos leidos de base de datos */
    private DefaultTableModel modelo;

    /**
     * Crea una instancia de la clase MySQL y realiza todo el cdigo de
     * conexin, consulta y muestra de resultados.
     */
    public PruebaMySQL()
    {
        // Se mete todo en un try por los posibles errores de MySQL
        try
        {
            // Se instancian las clases necesarias
            bd = new BaseDeDatos();
            modelo = new DefaultTableModel();
            tabla = new TablaDeDatos();

            // Se comienza.
            bd.estableceConexion();
            tabla.creaYMuestraVentana();

            // Bucle infinito, cada segundo se reconsulta la base de datos
            // y se muestran los resultados en pantalla
            while (true)
            {
                ResultSet rs = bd.dameListaPersonas();
                ConversorResultSetADefaultTableModel.rellena(rs, modelo);
                tabla.tomaDatos(modelo);
                Thread.sleep(1000);
            }
        } catch (Exception e)
        {
            e.printStackTrace();
        }
    }

    /**
     * Mtodo principal, instancia una clase PruebaMySQL
     * 
     * @param args
     *            the command line arguments
     */
    public static void main(String[] args)
    {
        new PruebaMySQL();
    }

}
